<?php
/*
Plugin Name: LazyLoad CSS
Plugin URI: 
Description: A plugin to lazy-load unnecessary CSS stylesheet files to improve FCP, LCP (Largest Contentful Paint), and overall performance.
Version: 1.0.0
Author: Uzair
Author URI: https://easywpstuff.com
License: GPL2
*/


// If this file is called directly, abort.
if (!defined("WPINC")){
	die;
}

// Settings page
include('inc/options.php');


require_once dirname(__FILE__) . '/lib/simple_html_dom.php';

// Replace stylesheet attribute value
function easyopt_lazyload_replace_link_rel($content) {
  if (empty($content)) {
    return $content;
  }
  // Load the content into a SimpleHTMLDOM object
  $html = eop_str_get_html($content, false, true, 'UTF-8', false, PHP_EOL, ' ');

  if (!$html) {
    return $content;
  }

  $href_strings = get_option('href_strings');
  if (empty($href_strings)) {
    return $content;
  }

  foreach ($href_strings as $href_string) {
    if (empty(trim($href_string))) {
      continue;
    }
    // Select link elements with an href attribute that contains the specified string
    $links = $html->find("link[href*='" . trim($href_string) . "']");
    foreach ($links as $link) {
      if ($link->hasAttribute( 'rel' ) ) {
        $rel = $link->rel;
        if ($rel == 'stylesheet') {
          $link->rel = 'lazycss';
        }
      } else {
        $link->rel = 'lazycss';
      }
    }
  }
  // Convert the modified HTML object back into an HTML string
  $html = $html->save();
  return $html;
}

function easy_opt_addlazyloadscript( $buffer ) { 
	$buffer = str_replace('</body>', '<script>window.onload=function(){window.scrollY>=500&&LazyCssscript()};function LazyCssscript(){document.querySelectorAll("link[rel=lazycss]").forEach(function(o){o.setAttribute("rel","stylesheet")}),document.removeEventListener("scroll",LazyCssscript),document.removeEventListener("touchstart",LazyCssscript),document.removeEventListener("mouseover",LazyCssscript)}document.addEventListener("scroll",LazyCssscript),document.addEventListener("touchstart",LazyCssscript),document.addEventListener("mouseover",LazyCssscript);</script>
	</body>', $buffer);
	return $buffer;
}

function run_easyopt_template_redirect() {
	//ob_start();
	ob_start( 'easyopt_lazyload_replace_link_rel',0, PHP_OUTPUT_HANDLER_REMOVABLE );
	ob_start( 'easy_opt_addlazyloadscript',0, PHP_OUTPUT_HANDLER_REMOVABLE );
}
add_action( 'template_redirect', 'run_easyopt_template_redirect', 999 );

function rrun_easyopt_template_redirect() {
	//ob_start(); 
	
	ob_start( 'easyopt_lazyload_replace_link_rel',0, PHP_OUTPUT_HANDLER_REMOVABLE );
	//ob_start( 'easyopt_replace_inline_style',0, PHP_OUTPUT_HANDLER_REMOVABLE );
	ob_start( 'easy_opt_addlazyloadscript',0, PHP_OUTPUT_HANDLER_REMOVABLE );
	
}

//add_action( 'plugins_loaded', 'easy_opt_loader' );
function easy_opt_loader() {
	if ( !is_admin() ) {
     add_action('setup_theme', 'rrun_easyopt_template_redirect', 999);
	}
}

// Enqueue admin script on option page
function easy_opt_admin_enqueue_scripts( $hook_suffix ) {
  // Check if we are on the option page
  if ( 'settings_page_easy-optimizer' !== $hook_suffix ) {
    return;
  }

  wp_enqueue_script( 'easy-add-remove-fields', plugin_dir_url( __FILE__ ) . 'assets/script.js', array('jquery'), '1.0.0', true );
}
add_action( 'admin_enqueue_scripts', 'easy_opt_admin_enqueue_scripts' );


// enqueue admin styles on option page
function easy_opt_admin_enqueue_plugin_styles( $hook ) {
  if ( 'settings_page_easy-optimizer' === $hook ) {
    wp_enqueue_style( 'lazyplugin-styles', plugin_dir_url( __FILE__ ) . 'assets/style.css' );
  }
}
add_action( 'admin_enqueue_scripts', 'easy_opt_admin_enqueue_plugin_styles' );


// plugin action settings
function easy_opt_add_settings_link( $links ) {
  $settings_link = '<a href="' . admin_url( 'options-general.php?page=easy-optimizer' ) . '">' . __( 'Settings' ) . '</a>';
  array_unshift( $links, $settings_link );
  return $links;
}
add_filter( 'plugin_action_links_' . plugin_basename( __FILE__ ), 'easy_opt_add_settings_link' );
